@@ -14,7 +14,12 @@ _ = Translator("Filter", __file__)
 
 @cog_i18n(_)
 class Filter(commands.Cog):
-    """Filter unwanted words and phrases from text channels."""
+    """This cog is designed for "filtering" unwanted words and phrases from a server.
+
+    It provides tools to manage a list of words or sentences, and to customize automatic actions to be taken against users who use those words in channels or in their name/nickname.
+
+    This can be used to prevent inappropriate language, off-topic discussions, invite links, and more.
+    """
 
     def __init__(self, bot: Red):
         super().__init__()
@@ -32,7 +37,6 @@ class Filter(commands.Cog):
         self.config.register_guild(**default_guild_settings)
         self.config.register_member(**default_member_settings)
         self.config.register_channel(**default_channel_settings)
-        self.register_task = self.bot.loop.create_task(self.register_filterban())
         self.pattern_cache = {}
 
     async def red_delete_data_for_user(
@@ -50,23 +54,33 @@ class Filter(commands.Cog):
             if user_id in guild_data:
                 await self.config.member_from_ids(guild_id, user_id).clear()
 
-    def cog_unload(self):
-        self.register_task.cancel()
+    async def initialize(self) -> None:
+        await self.register_casetypes()
 
     @staticmethod
-    async def register_filterban():
-        try:
-            await modlog.register_casetype(
-                "filterban", False, ":filing_cabinet: :hammer:", "Filter ban"
-            )
-        except RuntimeError:
-            pass
+    async def register_casetypes() -> None:
+        await modlog.register_casetypes(
+            [
+                {
+                    "name": "filterban",
+                    "default_setting": False,
+                    "image": "\N{FILE CABINET}\N{VARIATION SELECTOR-16} \N{HAMMER}",
+                    "case_str": "Filter ban",
+                },
+                {
+                    "name": "filterhit",
+                    "default_setting": False,
+                    "image": "\N{FILE CABINET}\N{VARIATION SELECTOR-16}",
+                    "case_str": "Filter hit",
+                },
+            ]
+        )
 
     @commands.group()
     @commands.guild_only()
     @checks.admin_or_permissions(manage_guild=True)
     async def filterset(self, ctx: commands.Context):
-        """Manage filter settings."""
+        """Base command to manage filter settings."""
         pass
 
     @filterset.command(name="defaultname")
@@ -77,6 +91,13 @@ class Filter(commands.Cog):
         (to toggle, run `[p]filter names`).
 
         The default name used is *John Doe*.
+
+        Example:
+            - `[p]filterset defaultname Missingno`
+
+        **Arguments:**
+
+        - `<name>` The new nickname to assign.
         """
         guild = ctx.guild
         await self.config.guild(guild).filter_default_name.set(name)
@@ -90,6 +111,15 @@ class Filter(commands.Cog):
         `<timeframe>` seconds.
 
         Set both to zero to disable autoban.
+
+        Examples:
+            - `[p]filterset ban 5 5` - Ban users who say 5 filtered words in 5 seconds.
+            - `[p]filterset ban 2 20` - Ban users who say 2 filtered words in 20 seconds.
+
+        **Arguments:**
+
+        - `<count>` The amount of filtered words required to trigger a ban.
+        - `<timeframe>` The period of time in which too many filtered words will trigger a ban.
         """
         if (count <= 0) != (timeframe <= 0):
             await ctx.send(
@@ -114,7 +144,7 @@ class Filter(commands.Cog):
     @commands.guild_only()
     @checks.mod_or_permissions(manage_messages=True)
     async def _filter(self, ctx: commands.Context):
-        """Add or remove words from server filter.
+        """Base command to add or remove words from the server filter.
 
         Use double quotes to add or remove sentences.
         """
@@ -122,7 +152,7 @@ class Filter(commands.Cog):
 
     @_filter.command(name="list")
     async def _global_list(self, ctx: commands.Context):
-        """Send a list of this servers filtered words."""
+        """Send a list of this server's filtered words."""
         server = ctx.guild
         author = ctx.author
         word_list = await self.config.guild(server).filter()
@@ -139,7 +169,7 @@ class Filter(commands.Cog):
 
     @_filter.group(name="channel")
     async def _filter_channel(self, ctx: commands.Context):
-        """Add or remove words from channel filter.
+        """Base command to add or remove words from the channel filter.
 
         Use double quotes to add or remove sentences.
         """
@@ -147,7 +177,7 @@ class Filter(commands.Cog):
 
     @_filter_channel.command(name="list")
     async def _channel_list(self, ctx: commands.Context):
-        """Send the list of the channel's filtered words."""
+        """Send a list of the channel's filtered words."""
         channel = ctx.channel
         author = ctx.author
         word_list = await self.config.channel(channel).filter()
@@ -162,15 +192,19 @@ class Filter(commands.Cog):
         except discord.Forbidden:
             await ctx.send(_("I can't send direct messages to you."))
 
-    @_filter_channel.command("add")
+    @_filter_channel.command(name="add", require_var_positional=True)
     async def filter_channel_add(self, ctx: commands.Context, *words: str):
         """Add words to the filter.
 
         Use double quotes to add sentences.
 
         Examples:
-        - `[p]filter channel add word1 word2 word3`
-        - `[p]filter channel add "This is a sentence"`
+            - `[p]filter channel add word1 word2 word3`
+            - `[p]filter channel add "This is a sentence"`
+
+        **Arguments:**
+
+        - `[words...]` The words or sentences to filter.
         """
         channel = ctx.channel
         added = await self.add_to_filter(channel, words)
@@ -180,15 +214,19 @@ class Filter(commands.Cog):
         else:
             await ctx.send(_("Words already in the filter."))
 
-    @_filter_channel.command("remove")
+    @_filter_channel.command(name="delete", aliases=["remove", "del"], require_var_positional=True)
     async def filter_channel_remove(self, ctx: commands.Context, *words: str):
         """Remove words from the filter.
 
         Use double quotes to remove sentences.
 
         Examples:
-        - `[p]filter channel remove word1 word2 word3`
-        - `[p]filter channel remove "This is a sentence"`
+            - `[p]filter channel remove word1 word2 word3`
+            - `[p]filter channel remove "This is a sentence"`
+
+        **Arguments:**
+
+        - `[words...]` The words or sentences to no longer filter.
         """
         channel = ctx.channel
         removed = await self.remove_from_filter(channel, words)
@@ -198,15 +236,19 @@ class Filter(commands.Cog):
         else:
             await ctx.send(_("Those words weren't in the filter."))
 
-    @_filter.command(name="add")
+    @_filter.command(name="add", require_var_positional=True)
     async def filter_add(self, ctx: commands.Context, *words: str):
         """Add words to the filter.
 
         Use double quotes to add sentences.
 
         Examples:
-        - `[p]filter add word1 word2 word3`
-        - `[p]filter add "This is a sentence"`
+            - `[p]filter add word1 word2 word3`
+            - `[p]filter add "This is a sentence"`
+
+        **Arguments:**
+
+        - `[words...]` The words or sentences to filter.
         """
         server = ctx.guild
         added = await self.add_to_filter(server, words)
@@ -216,15 +258,19 @@ class Filter(commands.Cog):
         else:
             await ctx.send(_("Those words were already in the filter."))
 
-    @_filter.command(name="delete", aliases=["remove", "del"])
+    @_filter.command(name="delete", aliases=["remove", "del"], require_var_positional=True)
     async def filter_remove(self, ctx: commands.Context, *words: str):
         """Remove words from the filter.
 
         Use double quotes to remove sentences.
 
         Examples:
-        - `[p]filter remove word1 word2 word3`
-        - `[p]filter remove "This is a sentence"`
+            - `[p]filter remove word1 word2 word3`
+            - `[p]filter remove "This is a sentence"`
+
+        **Arguments:**
+
+        - `[words...]` The words or sentences to no longer filter.
         """
         server = ctx.guild
         removed = await self.remove_from_filter(server, words)
@@ -354,6 +400,20 @@ class Filter(commands.Cog):
         hits = await self.filter_hits(message.content, message.channel)
 
         if hits:
+            await modlog.create_case(
+                bot=self.bot,
+                guild=guild,
+                created_at=message.created_at.replace(tzinfo=timezone.utc),
+                action_type="filterhit",
+                user=author,
+                moderator=guild.me,
+                reason=(
+                    _("Filtered words used: {words}").format(words=humanize_list(list(hits)))
+                    if len(hits) > 1
+                    else _("Filtered word used: {word}").format(word=list(hits)[0])
+                ),
+                channel=message.channel,
+            )
             try:
                 await message.delete()
             except discord.HTTPException:
@@ -434,7 +494,6 @@ class Filter(commands.Cog):
         await set_contextual_locales_from_guild(self.bot, guild)
 
         if await self.filter_hits(member.display_name, member.guild):
-
             name_to_use = guild_data["filter_default_name"]
             reason = _("Filtered nickname") if member.nick else _("Filtered name")
             try:
